#!/bin/bash

set -e

cd $(dirname $0)

# uses the program unzip and wget - for ubuntu just do
# sudo apt-get install unzip
# sudo apt-get install wget
# see ranking of solver: https://maxsat-evaluations.github.io/2022/results/complete/weighted/summary.html


weightedMaxSATSolver=("CGSS" "Cashwmaxsat-CorePlus" "Cashwmaxsat-Plus" "EvalMaxSAT" "Exact" "MaxHS" "UWrMaxSat-SCIP" "UWrMaxSat" "WMaxCDCL-BandAll" "WMaxCDCL")

#pureUnweightedMaxSATSolver=("MaxCDCL" "Open-WBO")

# Get all MaxSATSolver from 2022 MaxSAT evaluation
for mssolver in "${weightedMaxSATSolver[@]}"; do
  if [ ! -d "$mssolver" ]; then
    wget https://maxsat-evaluations.github.io/2022/mse22-solver-src/complete/"$mssolver".zip
    unzip "$mssolver".zip
    rm "$mssolver".zip
  fi
done

# Get Pacose from 2021 MaxSAT evaluation
wget https://maxsat-evaluations.github.io/2021/mse21-solver-src/complete/pacose.zip
unzip pacose.zip
rm pacose.zip

# Get Z3 solver
if [ ! -d "z3" ]; then
  git clone https://github.com/Z3Prover/z3.git
fi
cd z3
python scripts/mk_make.py
cd build
make -j8
sudo make install
cd ../..

# Get MaxPre2 MaxSAT preprocessor
if [ ! -d "maxpre2" ]; then
  git clone https://bitbucket.org/coreo-group/maxpre2.git
fi
cd maxpre2
make -j
cd ..

# install wcnfverifier
cd wcnfverifier
make -j8

# clone kissat for the wcnfverifier
if [ ! -d "kissat" ]; then
  git clone https://github.com/arminbiere/kissat.git
fi

# install kissat SAT solver for wcnfverifier
cd kissat
./configure && make -j
cd ../..

